use maud::{PreEscaped, Render, html};

use crate::ui::{
    UIWidget,
    htmx::{Event, HTMXAttributes, SwapStrategy},
    prelude::Div,
};

pub fn ClickToLoad<T: UIWidget + 'static>(reference: &str, widget: T) -> PreEscaped<String> {
    html! {
        button hx-get=(reference)
                        hx-target="this"
                        hx-swap="outerHTML" {
         (widget)
        };
    }
}

pub fn LazyLoad<T: UIWidget + 'static>(reference: &str, widget: T) -> PreEscaped<String> {
    html! {
        div hx-get=(reference) hx-trigger="load" {
            div class="htmx-indicator" {
                (widget)
            }
    };
        }
}

pub fn InfinityScroll<T: UIWidget + 'static>(content: T, fetch_url: &str) -> PreEscaped<String> {
    html! {
      (content)
      (Div()
        .hx_get(fetch_url)
        .hx_swap(SwapStrategy::outerHTML)
        .hx_trigger(Event::on_revealed()))
    }
}
